@@ -1,6 +1,5 @@
 import os
 import re
-import shutil
 from contextlib import contextmanager
 
 
@@ -79,13 +78,12 @@ def render_latex(exam, subs=None):
             latex = latex.replace(f"<{k.upper()}>", v)
     if not os.path.exists("temp"):
         os.mkdir("temp")
-    with rel_open("temp/out.tex", "w+") as f:
+    with open("temp/out.tex", "w+") as f:
         f.write(latex)
     old = os.getcwd()
-    os.chdir(os.path.dirname(os.path.abspath(__file__)))
     os.system("cd temp && pdflatex --shell-escape -interaction=nonstopmode out.tex")
     # os.system("cd temp && pdflatex --shell-escape -interaction=nonstopmode out.tex")
-    with rel_open("temp/out.pdf", "rb") as f:
+    with open("temp/out.pdf", "rb") as f:
         os.chdir(old)
         yield f.read()
     # shutil.rmtree("temp")
